unit PreviewFrm;

interface

uses
  SysUtils, Types, Classes, Variants, QTypes, QGraphics, QControls, QForms, 
  QDialogs, QStdCtrls, QExtCtrls, QButtons,Math,cad;

type
  TPreviewForm = class(TForm)
    Panel1: TPanel;
    ScrollBox1: TScrollBox;
    Label1: TLabel;
    cmbZoom: TComboBox;
    bbtnPrintCurrentLayer: TBitBtn;
    bbtnPrint: TBitBtn;
    Image1: TImage;
    procedure FormResize(Sender: TObject);
    procedure cmbZoomChange(Sender: TObject);
    procedure bbtnPrintClick(Sender: TObject);
    procedure bbtnPrintCurrentLayerClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    TheScale: double;
    procedure AdjustPosition;
  end;

var
  PreviewForm: TPreviewForm;

implementation

uses MainFrm;

{$R *.xfm}

procedure TPreviewForm.FormResize(Sender: TObject);
begin
  cmbZoomChange(Sender);
end;

procedure TPreviewForm.cmbZoomChange(Sender: TObject);
var
  ScaleX, ScaleY: double;
begin
  with cmbZoom do
  begin
    case ItemIndex of
      0: TheScale := 0.5;
      1: TheScale := 1.0;
      2: TheScale := 1.5;
      3: TheScale := 2.0;
      4: //Page Width
        TheScale := ScrollBox1.Width / MainForm.MyCAD1.width;
      5: //Whole Page
        begin
          ScaleX := ScrollBox1.Width / MainForm.MyCAD1.Width;
          ScaleY := ScrollBox1.Height / MainForm.MyCAD1.Height;
          if (ScaleX <= ScaleY) then
            TheScale := ScaleX
          else
            TheScale := ScaleY;
        end;

      6: TheScale := 1.0;
    end;

    MainForm.MyCAD1.PrintPreview([],Image1.Picture.Bitmap, TheScale * 0.9);
    AdjustPosition;
  end;
end;

procedure TPreviewForm.AdjustPosition;
begin
  MainForm.Scrollbox1.HorzScrollBar.Position := 0;
  MainForm.Scrollbox1.VertScrollBar.Position := 0;

  PreviewForm.Image1.Width := PreviewForm.Image1.picture.Bitmap.width;
  PreviewForm.Image1.Height := PreviewForm.Image1.picture.Bitmap.Height;
  if PreviewForm.Image1.Width < MainForm.ScrollBox1.Width then
    PreviewForm.Image1.Left := (MainForm.ScrollBox1.Width - PreviewForm.Image1.Width) div 2
  else
    PreviewForm.Image1.Left := 0;

  if PreviewForm.Image1.Height < MainForm.ScrollBox1.Height then
    PreviewForm.Image1.Top := (MainForm.ScrollBox1.Height - PreviewForm.Image1.Height) div 2
  else
    PreviewForm.Image1.Top := 0;

  MainForm.Scrollbox1.HorzScrollBar.Range := max(PreviewForm.Image1.Width, MainForm.ScrollBox1.Width);
  MainForm.Scrollbox1.VertScrollBar.Range := max(PreviewForm.Image1.Height, MainForm.ScrollBox1.Height);

  MainForm.Scrollbox1.ScrollInView(PreviewForm.Image1);
end;

procedure TPreviewForm.bbtnPrintClick(Sender: TObject);
begin
  MainForm.MyCAD1.Print([],1.0);
end;

procedure TPreviewForm.bbtnPrintCurrentLayerClick(Sender: TObject);
begin
  MainForm.MyCAD1.Print([MainForm.MyCAD1.CurrentLayerId], 1.0);
end;

end.
