unit SetupFrm;

interface

uses
  SysUtils, Types, Classes, Variants, QTypes, QGraphics, QControls, QForms,
  QDialogs, QStdCtrls, QButtons, QExtCtrls, QComCtrls,cad;

type
  TSetupForm = class(TForm)
    GroupBox1: TGroupBox;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    cmbStyle: TComboBox;
    seWidth: TSpinEdit;
    seHeight: TSpinEdit;
    GroupBox2: TGroupBox;
    Panel1: TPanel;
    Image1: TImage;
    Label5: TLabel;
    cmbPosition: TComboBox;
    btnLoad: TButton;
    btnClear: TButton;
    GroupBox3: TGroupBox;
    cbSnapEnable: TCheckBox;
    sePixels: TSpinEdit;
    Label6: TLabel;
    GroupBox4: TGroupBox;
    cbShowGrid: TCheckBox;
    Label7: TLabel;
    seGridWidth: TSpinEdit;
    Label8: TLabel;
    seGridHeight: TSpinEdit;
    GroupBox5: TGroupBox;
    Label9: TLabel;
    cmbUnit: TComboBox;
    Label10: TLabel;
    seRatio: TSpinEdit;
    Label11: TLabel;
    btnSet: TButton;
    bbtnClose: TBitBtn;
    OpenDialog1: TOpenDialog;
    ColorDialog1: TColorDialog;
    Shape1: TShape;
    sbtnChangeColor: TSpeedButton;
    procedure bbtnCloseClick(Sender: TObject);
    procedure cmbStyleChange(Sender: TObject);
    procedure btnClearClick(Sender: TObject);
    procedure btnLoadClick(Sender: TObject);
    procedure cmbPositionChange(Sender: TObject);
    procedure cbSnapEnableClick(Sender: TObject);
    procedure cbShowGridClick(Sender: TObject);
    procedure cmbUnitChange(Sender: TObject);
    procedure btnSetClick(Sender: TObject);
    procedure Image1Click(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure seWidthChanged(Sender: TObject; NewValue: Integer);
    procedure seHeightChanged(Sender: TObject; NewValue: Integer);
    procedure seGridWidthChanged(Sender: TObject; NewValue: Integer);
    procedure seGridHeightChanged(Sender: TObject; NewValue: Integer);
    procedure sePixelsChanged(Sender: TObject; NewValue: Integer);
    procedure sbtnChangeColorClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  SetupForm: TSetupForm;

implementation

uses MainFrm;

{$R *.xfm}

procedure TSetupForm.bbtnCloseClick(Sender: TObject);
begin
  Close;  
end;

procedure TSetupForm.cmbStyleChange(Sender: TObject);
begin
  with MainForm do
  begin
    MyCAD1.PageStyle:=TPageStyle(cmbStyle.ItemIndex);
    seWidth.value := MyCAD1.Width;
    seHeight.value := MyCAD1.Height;
  end;
  MainForm.CenterCAD;
end;

procedure TSetupForm.btnClearClick(Sender: TObject);
begin
  MainForm.MyCAD1.BkBitmap:=nil;
  Image1.Picture.Bitmap:=nil;
end;

procedure TSetupForm.btnLoadClick(Sender: TObject);
var
  mybitmap: TBitmap;
begin
  if OpenDialog1.Execute then
  begin
    myBitmap := TBitmap.Create;

    mybitmap.LoadFromFile(OpenDialog1.FileName);
    MainForm.MyCAD1.BkBitmap:=MyBitmap;
    Image1.Picture.LoadFromFile(OpenDialog1.FileName);

    MyBitmap.Free;

  end;
end;

procedure TSetupForm.cmbPositionChange(Sender: TObject);
begin
  {with MainForm do
    case cmbPosition.ItemIndex of
      0: MyCAD1.BkBitmapMode := LeftTop;
      1: MyCAD1.BkBitmapMode := Center;
      2: MyCAD1.BkBitmapMode := Tiled;
      3: MyCAD1.BkBitmapMode := Stretch;
    end; }
  with MainForm do
  begin
    MyCAD1.BkBitmapMode:=TBkBitmapMode(cmbPosition.ItemIndex);
    MyCAD1.Repaint;
  end;
end;

procedure TSetupForm.cbSnapEnableClick(Sender: TObject);
begin
  MainForm.MyCAD1.Snap := cbSnapEnable.Checked;
  sePixels.Enabled := cbSnapEnable.Checked;
end;

procedure TSetupForm.cbShowGridClick(Sender: TObject);
begin
  MainForm.MyCAD1.GridOperation.GridShow := cbShowGrid.Checked;
  seGridWidth.Enabled:=cbShowGrid.Checked;
  seGridHeight.Enabled:=cbShowGrid.Checked;
end;

procedure TSetupForm.cmbUnitChange(Sender: TObject);
begin
  case cmbUnit.ItemIndex of
  0:MainForm.MyCAD1.TheUNIT:= inch;
  1:MainForm.MyCAD1.TheUNIT:= mm;
  2:MainForm.MyCAD1.TheUNIT:= pixel;
  end;
end;

procedure TSetupForm.btnSetClick(Sender: TObject);
begin
  MainForm.MyCAD1.Ratio:=seRatio.Value/100;
end;

procedure TSetupForm.Image1Click(Sender: TObject);
begin
  btnLoadClick(Sender);
end;

procedure TSetupForm.FormShow(Sender: TObject);
var
  ps:TPageStyle;
  bbm:TBkBitmapMode;

begin
  with MainForm do
  begin

    cbSnapEnable.Checked:=MyCAD1.Snap;
    if cbSnapEnable.checked then sePixels.Value:=MyCAD1.SnapPixels;

    //LoadColor
    Shape1.Color:=MyCAD1.ColorOfBackGround;


    //Load page style first.
    ps:=MyCAD1.PageStyle;
    cmbStyle.ItemIndex:=integer(ps);

    seWidth.Value := MyCAD1.Width;
    seHeight.Value := MyCAD1.Height;


    //Load picture and position first.
    bbm:=MyCAD1.BkBitmapMode;

    cmbPosition.ItemIndex:=Integer(bbm);

    //Load unit and ratio
    seRatio.Value:=trunc(MyCAD1.Ratio *100);

    cbShowGrid.Checked:=MyCAD1.GridOperation.GridShow;
    if cbShowGrid.Checked then
    begin
      seGridWidth.Value := MyCAD1.GridOperation.GridWidth;
      seGridHeight.Value := MyCAD1.GridOperation.GridHeight;
    end;
  end;

end;

procedure TSetupForm.seWidthChanged(Sender: TObject; NewValue: Integer);
begin
  MainForm.MyCAD1.Width:=seWidth.Value;
  //MainForm.MyCAD1.PageStyle:=TPageStyle(cmbStyle.ItemIndex);
  MainForm.CenterCAD;
end;

procedure TSetupForm.seHeightChanged(Sender: TObject; NewValue: Integer);
begin
  MainForm.MyCAD1.Height:=seHeight.Value;
  MainForm.CenterCAD;
end;

procedure TSetupForm.seGridWidthChanged(Sender: TObject;
  NewValue: Integer);
begin
  MainForm.MyCAD1.GridOperation.GridWidth:=seGridWidth.Value;
end;

procedure TSetupForm.seGridHeightChanged(Sender: TObject;
  NewValue: Integer);
begin
  MainForm.MyCAD1.GridOperation.GridHeight:=seGridHeight.Value;
end;

procedure TSetupForm.sePixelsChanged(Sender: TObject; NewValue: Integer);
begin
  with MainForm do
    if (sePixels.Value > MyCAD1.GridOperation.GridWidth) or
      (sePixels.Value > MyCAD1.GridOperation.GridHeight)
      then
    begin
      ShowMessage('Pixels is too many!');
      sePixels.Value := 3;
    end
    else
      MyCAD1.SnapPixels := sePixels.Value;
end;

procedure TSetupForm.sbtnChangeColorClick(Sender: TObject);
begin
  if ColorDialog1.Execute then
  begin
    Shape1.Color:=ColorDialog1.Color;
    MainForm.MyCAD1.ColorOfBackGround:=ColorDialog1.Color;
  end;
end;

end.
